hantekosc
=================

hantekosc.devices
------------------------

.. automodule:: hantekosc.devices
   :members:
   :undoc-members:
   :show-inheritance:

hantekosc.oscilloscope
-----------------------------

.. automodule:: hantekosc.oscilloscope
   :members:
   :undoc-members:
   :show-inheritance:

hantekosc.channel
------------------------

.. automodule:: hantekosc.channel
   :members:
   :undoc-members:
   :show-inheritance:
